@@ -32,6 +32,8 @@
 #include <glib.h>
 #include "registry.h"
 #include <dbus/dbus-glib.h>
+#include <gconf/gconf-client.h>
+
 
 #define spi_get_display() GDK_DISPLAY()
 
@@ -41,6 +43,8 @@ static void set_gtk_path (DBusGProxy *gsm);
 #endif
 static void set_gtk_modules (DBusGProxy *gsm);
 
+#define CORBA_GCONF_KEY  "/desktop/gnome/interface/at-spi-corba"
+
 #define SM_DBUS_NAME      "org.gnome.SessionManager"
 #define SM_DBUS_PATH      "/org/gnome/SessionManager"
 #define SM_DBUS_INTERFACE "org.gnome.SessionManager"
@@ -112,6 +116,12 @@ query_end_session_cb (guint flags, gpointer data)
 static void
 end_session_cb (guint flags, gpointer data)
 {
+        Atom  AT_SPI_IOR = XInternAtom (spi_get_display (), "AT_SPI_IOR", TRUE);
+        XDeleteProperty (spi_get_display(),
+                         XDefaultRootWindow (spi_get_display ()),
+                         AT_SPI_IOR);
+        XFlush (spi_get_display());
+
         end_session_response (TRUE, NULL);
         bonobo_main_quit ();
 }
@@ -177,6 +187,16 @@ main (int argc, char **argv)
   DBusGProxy      *gsm;
   GError          *error;
 
+  GConfClient *gconf_client;
+  gboolean corba_set;
+
+  gconf_client = gconf_client_get_default ();
+  corba_set = gconf_client_get_bool (gconf_client, CORBA_GCONF_KEY, NULL);
+  g_object_unref (gconf_client);
+
+  if (!corba_set)
+    return 0;
+
   if (!bonobo_init (&argc, argv))
     {
       g_error ("Could not initialize oaf / Bonobo");
